@@ -1,7 +1,7 @@
 function erase_compiled_function(func)
 % erase compiled function with name 'func'
 
-% Copyright (C) 2006-2008 Dynare Team
+% Copyright (C) 2006-2009 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -18,10 +18,7 @@ function erase_compiled_function(func)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-    if exist([func '.dll'])
-      clear([func '.dll'])
-      delete([func '.dll'])
-    elseif exist ([func '.mexw32'])
-      clear([func '.dll'])
-      delete([func '.mexw32'])
+    if exist([func '.' mexext])
+      clear(func)
+      delete([func '.' mexext])
     end
